@@ -68,50 +68,7 @@ HackaMol::BondsAnglesDihedralsRole - Array traits for containers of HackaMol Bon
 
 =head1 VERSION
 
-version 0.00_01
-
-=head1 SYNOPSIS
-
-my $atom1 = HackaMol::Atom->new(
-    name    => 'O1',
-    coords  => [ V( 2.05274, 0.01959, -0.07701 ) ],
-    Z       => 8,
-);
-
-my $atom2 = HackaMol::Atom->new(
-    name    => 'H1',
-    coords  => [ V( 1.08388, 0.02164, -0.12303 ) ],
-    Z       => 1,
-);
-
-my $atom3 = HackaMol::Atom->new(
-    name    => 'H2',
-    coords  => [ V( 2.33092, 0.06098, -1.00332 ) ],
-    Z       => 1,
-);
-
-my $atom4 = HackaMol::Atom->new(
-    name    => 'Cl',
-    coords  => [ V(-0.91386, 0.02587, -0.21792 ) ],
-    Z       => 17,
-);
-
-my @atoms = ($atom1,$atom2,$atom3,$atom4);
-
-my $bond1 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[0,1]]);
-my $bond2 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[0,2]]);
-
-my @bonds = $atom1->all_bonds;
-
-my $angle1 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[1,0,2]]);
-my $angle2 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[0,1,3]]);
-
-my @angles = $atom1->all_angles;
-
-my $dihe1  = HackaMol::Dihedral->new(name=> 'test', atoms[@atoms]);
-my $dihe2  = HackaMol::Dihedral->new(name=> 'test', atoms[reverse @atoms]);
-
-my @dihes  = $atom1->all_dihedrals;
+version 0.00_02
 
 =head1 DESCRIPTION
 
@@ -130,31 +87,31 @@ ARRAY traits for the bonds attribute, respectively: push, get, set, elements, co
 
 push bond on to bonds array
 
-$group->push_bonds($bond1, $bond2, @otherbonds);
+  $group->push_bonds($bond1, $bond2, @otherbonds);
 
 =head2 all_bonds
 
 returns array of all elements in bonds array
 
-print $_->bond_order, "\n" foreach $group->all_bonds; 
+  print $_->bond_order, "\n" foreach $group->all_bonds; 
 
 =head2 get_bonds
 
 return element by index from bonds array
 
-print $group->get_bonds(1); # returns $bond2 from that pushed above
+  print $group->get_bonds(1); # returns $bond2 from that pushed above
 
 =head2 set_bonds
 
 set bonds array by index
 
-$group->set_bonds(1, $bond1);
+  $group->set_bonds(1, $bond1);
 
 =head2 count_bonds
 
 return number of bonds in the array  
 
-print $group->count_bonds; 
+  print $group->count_bonds; 
 
 =head2 delete_bonds
 
@@ -176,6 +133,62 @@ ARRAY traits for the bonds attribute, respectively: push, get, set, elements, co
 
 Analogous to those for bonds.
 
+=head1 SYNOPSIS
+    use HackaMol::Atom;
+    use HackaMol::Angle;
+    use HackaMol::Dihedral;
+
+    my $atom1 = HackaMol::Atom->new(
+        name    => 'O1',
+        coords  => [ V( 2.05274, 0.01959, -0.07701 ) ],
+        Z       => 8,
+    );
+    
+    my $atom2 = HackaMol::Atom->new(
+        name    => 'H1',
+        coords  => [ V( 1.08388, 0.02164, -0.12303 ) ],
+        Z       => 1,
+    );
+    
+    my $atom3 = HackaMol::Atom->new(
+        name    => 'H2',
+    coords  => [ V( 2.33092, 0.06098, -1.00332 ) ],
+    Z       => 1,
+    );
+    
+    my $atom4 = HackaMol::Atom->new(
+        name    => 'Cl',
+        coords  => [ V(-0.91386, 0.02587, -0.21792 ) ],
+        Z       => 17,
+    );
+    
+    my @atoms = ($atom1,$atom2,$atom3,$atom4);
+    
+    my $bond1 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[0,1]]);
+    my $bond2 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[0,2]]);
+    
+    my @bonds = $atom1->all_bonds;
+
+    my $angle1 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[1,0,2]]);
+    my $angle2 = HackaMol::Angle->new(name=> 'test', atoms[@atoms[0,1,3]]);
+    
+    my @angles = $atom1->all_angles;
+    
+    my $dihe1  = HackaMol::Dihedral->new(name=> 'test', atoms[@atoms]);
+    my $dihe2  = HackaMol::Dihedral->new(name=> 'test', atoms[reverse @atoms]);
+    
+    my @dihes  = $atom1->all_dihedrals;
+
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<HackaMol::Molecule>
+
+=back
+
 =head1 AUTHOR
 
 Demian Riccardi <demianriccardi@gmail.com>
